@@ -1,7 +1,5 @@
 import json
-import re
-from pathlib import Path
-from typing import TextIO
+from typing import Any, TextIO
 
 from wg_federation.data_transformation.loader.file.file_configuration_loader import FileConfigurationLoader
 from wg_federation.utils.utils import Utils
@@ -12,14 +10,10 @@ class JsonFileConfigurationLoader(FileConfigurationLoader):
     Read any configuration from JSON files
     """
 
-    @staticmethod
-    def get_supported_source() -> str:
-        return 'json_file'
-
-    def supports(self, source: str) -> bool:
+    def supports(self, source: Any) -> bool:
         return super().supports(source) and \
-            bool(re.match(r'^\.json$', Path(source).suffix, re.IGNORECASE))
+            Utils.has_extension(source, 'json')
 
-    @classmethod
-    def _load_file(cls, file: TextIO) -> dict:
+    def _load_file(self, file: TextIO) -> dict:
+        super()._load_file(file)
         return Utils.always_dict(json.load(file))
