@@ -11,10 +11,9 @@ from Cryptodome.Cipher import AES
 from Cryptodome.Hash import Poly1305
 from dependency_injector import containers, providers
 from nacl import public
-from systemd.journal import JournalHandler
 
-from wg_federation.constants import __version__
 from wg_federation.controller.api.hq_get_private_key_controller import HQGetPrivateKeyController
+from wg_federation.constants import __version__, HAS_SYSTEMD
 from wg_federation.controller.baseline.configure_logging_controller import ConfigureLoggingController
 from wg_federation.controller.bootstrap.hq_bootstrap_controller import HQBootstrapController
 from wg_federation.crypto.cryptographic_key_deriver import CryptographicKeyDeriver
@@ -51,6 +50,8 @@ from wg_federation.input.reader.environment_variable_reader import EnvironmentVa
 from wg_federation.observer.event_dispatcher import EventDispatcher
 from wg_federation.state.manager.state_data_manager import StateDataManager
 
+if HAS_SYSTEMD:
+    from systemd.journal import JournalHandler
 
 # Because it's how the DI lib works
 # pylint: disable=too-many-instance-attributes
@@ -75,7 +76,8 @@ class Container(containers.DynamicContainer):
         # logging
         _logger = logging.getLogger('root')
         _logger_console_handler = logging.StreamHandler()
-        _logger_syslog_handler = JournalHandler()
+        if HAS_SYSTEMD:
+            _logger_syslog_handler = JournalHandler()
 
         if early_debug:
             # Can help debug very early code, like input processing
@@ -84,10 +86,12 @@ class Container(containers.DynamicContainer):
             _logger_console_handler.setLevel(logging.DEBUG)
 
         _logger.addHandler(_logger_console_handler)
-        _logger.addHandler(_logger_syslog_handler)
+        if HAS_SYSTEMD:
+            _logger.addHandler(_logger_syslog_handler)
 
         self.logger_console_handler = providers.Object(_logger_console_handler)
-        self.logger_syslog_handler = providers.Object(_logger_syslog_handler)
+        if HAS_SYSTEMD:
+            self.logger_syslog_handler = providers.Object(_logger_syslog_handler)
 
         self.root_logger = providers.Object(_logger)
 
@@ -117,6 +121,7 @@ class Container(containers.DynamicContainer):
                     FileConfigurationLocker,
                     file_locker=portalocker,
                     path_lib=pathlib,
+                    os_lib=os,
                 ),
             ),
             logger=self.root_logger
